@@ -1,3 +1,5 @@
+import re
+
 from django.contrib.auth import get_user_model
 from django.contrib.auth.hashers import check_password
 from django.contrib.auth.tokens import default_token_generator
@@ -121,12 +123,23 @@ class TestRegisterView(APIRequestTestCase):
         """Unauthenticated Users should be able to register."""
         request = self.create_request('post', auth=False, data=self.data)
 
-        send_email_path = 'user_management.models.mixins.VerifyEmailMixin.send_validation_email'
-        with patch(send_email_path) as send:
-            response = self.view_class.as_view()(request)
+        response = self.view_class.as_view()(request)
 
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
-        send.assert_called_once_with()
+        self.assertEqual(len(mail.outbox), 1)
+
+        email = mail.outbox[0]
+        verify_url_regex = re.compile(
+            r'''
+                http://example\.com/\#/register/verify/
+                [0-9A-Za-z_\-]+/  # uid
+                [0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20}/  # token
+            ''',
+            re.VERBOSE,
+        )
+        self.assertRegex(email.body, verify_url_regex)
+        html_email = email.alternatives[0][0]
+        self.assertRegex(html_email, verify_url_regex)
 
         user = User.objects.get()
         self.assertEqual(user.name, self.data['name'])
@@ -143,12 +156,10 @@ class TestRegisterView(APIRequestTestCase):
         """An email should not be sent if email_verification_required is False."""
         request = self.create_request('post', auth=False, data=self.data)
 
-        send_email_path = 'user_management.models.mixins.VerifyEmailMixin.send_validation_email'
-        with patch(send_email_path) as send:
-            response = self.view_class.as_view()(request)
+        response = self.view_class.as_view()(request)
 
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
-        self.assertFalse(send.called)
+        self.assertEqual(len(mail.outbox), 0)
 
     def test_post_with_missing_data(self):
         """Password should not be sent back on failed request."""
