@@ -127,6 +127,15 @@ class TestUserManager(TestCase):
         user = self.manager.create_user(email)
         self.assertEqual(email.lower(), user.email)
 
+    def test_set_last_login(self):
+        email = 'valid@example.com'
+
+        before = timezone.now()
+        user = self.manager.create_user(email)
+        after = timezone.now()
+
+        self.assertTrue(before < user.last_login < after)
+
     def test_create_superuser(self):
         email = 'valid@example.com'
         password = 'password'
